@@ -131,6 +131,12 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
             refit or not. if refit, the model would use all data.
         """
         super().__init__(muti_grade=muti_grade, muti_index=muti_index, must_index=must_index)
+        if hasattr(estimator, "max_features"):
+            print("For estimator with 'max_features' attribute, the 'max_features' would changed with "
+                              "each sub-data. that is, The 'refit estimator' which with fixed 'max_features' could be with different performance.\n"
+                              "Please change and define 'max_features' (with other parameters fixed) by manual testing after Backforward!!!!\n"
+                              "Please change and define 'max_features' (with other parameters fixed) by manual testing after Backforward!!!!",
+                          )
         self.estimator = estimator
         self.n_type_feature_to_select = n_type_feature_to_select
         self.primary_feature = primary_feature
@@ -233,11 +239,23 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
                 slices = self.feature_unfold(slices)
                 data_x0 = x0[:, slices]
 
-                estimator.fit(data_x0, y0)
-                if hasattr(estimator, 'best_score_'):
-                    score0 = np.mean(estimator.best_score_)
+                if hasattr(self.estimator, "max_features"):
+                    if self.estimator.max_features>data_x0.shape[1]:
+                        estimator_ = clone(self.estimator)
+                        estimator_.max_features = data_x0.shape[1]
+
+                    else:
+                        estimator_ = estimator
                 else:
-                    score0 = np.mean(cross_val_score(estimator, data_x0, y0, cv=5))
+                    estimator_ = estimator
+
+                estimator_.fit(data_x0, y0)
+
+                if hasattr(estimator_, 'best_score_'):
+                    score0 = np.mean(estimator_.best_score_)
+                else:
+                    score0 = np.mean(cross_val_score(estimator_, data_x0, y0, cv=5))
+
             return score0
 
         score = partial(score_pri, x0=x, y0=y)
